# coding: utf-8

from itertools import tee

try:
    from itertools import izip
except ImportError:
    izip = zip


def pairwise(iterable):
    "s -> (s0,s1), (s1,s2), (s2, s3), ..."
    a, b = tee(iterable)
    next(b, None)
    return izip(a, b)


def bisect_search_left(a, x, key, lo=0, hi=None):
    if lo < 0:
        raise ValueError('lo must be non-negative')
    if hi is None:
        hi = len(a)

    while lo < hi:
        mid = (lo+hi) // 2
        if key(a[mid]) < x:
            lo = mid+1
        else:
            hi = mid
    return lo


def bisect_search(a, x, key, lo=0, hi=None):
    if lo < 0:
        raise ValueError('lo must be non-negative')
    if hi is None:
        hi = len(a)

    while lo < hi:
        mid = (lo+hi) // 2
        if x < key(a[mid]):
            hi = mid
        else:
            lo = mid+1
    return lo


bisect_search_right = bisect_search


class cached_property(object):

    def __init__(self, func):
        self.func = func
        self.__name__ = func.__name__
        self.__doc__ = func.__doc__
        self.__module__ = func.__module__

    def __get__(self, obj, cls):
        if obj is None:
            return self
        value = obj.__dict__[self.func.__name__] = self.func(obj)
        return value


def normalize_name(name):
    mappings = {
        u'中国 浙江 义乌市 义乌市': u'中国 浙江省 金华市 义乌市',
        u'中国 河南 济源市 济源市': u'中国 河南省 省直辖县级行政区划 济源市',
        u'中国 湖北 仙桃市 仙桃市': u'中国 湖北省 省直辖县级行政区划 仙桃市',
        u'中国 湖北 潜江市 潜江市': u'中国 湖北省 省直辖县级行政区划 潜江市',
        u'中国 湖北 天门市 天门市': u'中国 湖北省 省直辖县级行政区划 天门市',
        u'中国 湖北 神农架林区 神农架林区': u'中国 湖北省 省直辖县级行政区划 神农架林区',
        u'中国 广东 东莞市 东莞市': u'中国 广东省 东莞市',
        u'中国 广东 中山市 中山市': u'中国 广东省 中山市',
        u'中国 广东 顺德市 顺德市': u'中国 广东省 佛山市 顺德区',
        u'中国 海南 三亚市 三亚市': u'中国 海南省 三亚市 海棠区',
        u'中国 甘肃 嘉峪关市 嘉峪关市': u'中国 甘肃省 嘉峪关市',
        u'中国 新疆 石河子市 石河子市': u'中国 新疆维吾尔自治区 自治区直辖县级行政区划 石河子市',
        u'中国 新疆 阿拉尔市 阿拉尔市': u'中国 新疆维吾尔自治区 自治区直辖县级行政区划 阿拉尔市',
        u'中国 新疆 图木舒克市 图木舒克市': u'中国 新疆维吾尔自治区 自治区直辖县级行政区划 图木舒克市',
        u'中国 新疆 五家渠市 五家渠市': u'中国 新疆维吾尔自治区 自治区直辖县级行政区划 五家渠市',
        u"中国 内蒙古 兴安盟 科尔沁右中旗": u"中国 内蒙古 兴安盟 科尔沁右翼中旗",
        u"中国 广东 韶关市 乳源县": u"中国 广东 韶关市 乳源瑶族自治县",
        u"中国 云南 玉溪市 峨山县": u"中国 云南 玉溪市 峨山彝族自治县",
        u"中国 内蒙古 呼伦贝尔市 鄂温克旗": u"中国 内蒙古 呼伦贝尔市 鄂温克族自治旗",
        u"中国 新疆 克孜勒苏州 阿合奇县": u"中国 新疆 克孜勒苏柯尔克孜自治州 阿合奇县",
        u"中国 四川 凉山州 美姑县": u"中国 四川 凉山彝族自治州 美姑县",
        u"中国 四川 甘孜州 稻城县": u"中国 四川 甘孜藏族自治州 稻城县",
        u"中国 重庆 秀山县": u"中国 重庆 秀山土家族苗族自治县",
        u"中国 贵州 黔东南州 三穗县": u"中国 贵州 黔东南苗族侗族自治州 三穗县",
        u"中国 新疆 克孜勒苏州 阿图什市": u"中国 新疆 克孜勒苏柯尔克孜自治州 阿图什市",
        u"中国 云南 临沧市 耿马县": u"中国 云南 临沧市 耿马傣族佤族自治县",
        u"中国 贵州 黔南州 福泉市": u"中国 贵州 黔南布依族苗族自治州 福泉市",
        u"中国 黑龙江 齐齐哈尔市 梅里斯区": u"中国 黑龙江 齐齐哈尔市 梅里斯达斡尔族区",
        u"中国 新疆 巴音郭楞州 焉耆县": u"中国 新疆 巴音郭楞蒙古自治州 焉耆回族自治县",
        u"中国 内蒙古 乌兰察布市 察哈尔右中旗": u"中国 内蒙古 乌兰察布市 察哈尔右翼中旗",
        u"中国 甘肃 临夏回族自治州 积石山县": u"中国 甘肃 临夏回族自治州 积石山保安族东乡族撒拉族自治县",
        u"中国 贵州 黔东南州 黄平县": u"中国 贵州 黔东南苗族侗族自治州 黄平县",
        u"中国 四川 凉山州 会东县": u"中国 四川 凉山彝族自治州 会东县",
        u"中国 黑龙江 大庆市 杜尔伯特县": u"中国 黑龙江 大庆市 杜尔伯特蒙古族自治县",
        u"中国 贵州 黔南州 三都县": u"中国 贵州 黔南布依族苗族自治州 三都水族自治县",
        u"中国 贵州 黔南州 长顺县": u"中国 贵州 黔南布依族苗族自治州 长顺县",
        u"中国 甘肃 甘南州 卓尼县": u"中国 甘肃 甘南藏族自治州 卓尼县",
        u"中国 云南 西双版纳州 景洪市": u"中国 云南 西双版纳傣族自治州 景洪市",
        u"中国 广西 桂林市 恭城县": u"中国 广西 桂林市 恭城瑶族自治县",
        u"中国 吉林 白山市 长白县": u"中国 吉林 白山市 长白朝鲜族自治县",
        u"中国 新疆 克孜勒苏州 阿克陶县": u"中国 新疆 克孜勒苏柯尔克孜自治州 阿克陶县",
        u"中国 新疆 博尔塔拉州 博乐市": u"中国 新疆 博尔塔拉蒙古自治州 博乐市",
        u"中国 云南 大理州 鹤庆县": u"中国 云南 大理白族自治州 鹤庆县",
        u"中国 青海 玉树州 玉树县": u"中国 青海 玉树藏族自治州 玉树县",
        u"中国 四川 绵阳市 北川县": u"中国 四川 绵阳市 北川羌族自治县",
        u"中国 青海 海东地区 化隆县": u"中国 青海 海东地区 化隆回族自治县",
        u"中国 湖南 永州市 江华县": u"中国 湖南 永州市 江华瑶族自治县",
        u"中国 湖北 恩施州 利川市": u"中国 湖北 恩施土家族苗族自治州 利川市",
        u"中国 青海 海北州 海晏县": u"中国 青海 海北藏族自治州 海晏县",
        u"中国 贵州 安顺市 镇宁县": u"中国 贵州 安顺市 镇宁布依族苗族自治县",
        u"中国 云南 文山州 麻栗坡县": u"中国 云南 文山壮族苗族自治州 麻栗坡县",
        u"中国 湖南 湘西州 龙山县": u"中国 湖南 湘西土家族苗族自治州 龙山县",
        u"中国 青海 海西州 德令哈市": u"中国 青海 海西蒙古族藏族自治州 德令哈市",
        u"中国 贵州 遵义市 道真县": u"中国 贵州 遵义市 道真仡佬族苗族自治县",
        u"中国 四川 甘孜州 色达县": u"中国 四川 甘孜藏族自治州 色达县",
        u"中国 河北 承德市 宽城县": u"中国 河北 承德市 宽城满族自治县",
        u"中国 甘肃 张掖市 肃南县": u"中国 甘肃 张掖市 肃南裕固族自治县",
        u"中国 青海 海东地区 民和县": u"中国 青海 海东地区 民和回族土族自治县",
        u"中国 青海 果洛州 班玛县": u"中国 青海 果洛藏族自治州 班玛县",
        u"中国 贵州 黔西南州 贞丰县": u"中国 贵州 黔西南布依族苗族自治州 贞丰县",
        u"中国 湖南 怀化市 麻阳县": u"中国 湖南 怀化市 麻阳苗族自治县",
        u"中国 青海 黄南州 泽库县": u"中国 青海 黄南藏族自治州 泽库县",
        u"中国 湖南 湘西州 古丈县": u"中国 湖南 湘西土家族苗族自治州 古丈县",
        u"中国 四川 甘孜州 得荣县": u"中国 四川 甘孜藏族自治州 得荣县",
        u"中国 贵州 黔南州 惠水县": u"中国 贵州 黔南布依族苗族自治州 惠水县",
        u"中国 青海 海西州 乌兰县": u"中国 青海 海西蒙古族藏族自治州 乌兰县",
        u"中国 云南 普洱市 镇沅县": u"中国 云南 普洱市 镇沅彝族哈尼族拉祜族自治县",
        u"中国 湖北 恩施州 宣恩县": u"中国 湖北 恩施土家族苗族自治州 宣恩县",
        u"中国 甘肃 临夏州": u"中国 甘肃 临夏回族自治州",
        u"中国 内蒙古 呼伦贝尔市 莫力达瓦旗": u"中国 内蒙古 呼伦贝尔市 莫力达瓦达斡尔族自治旗",
        u"中国 云南 玉溪市 元江县": u"中国 云南 玉溪市 元江哈尼族彝族傣族自治县",
        u"中国 青海 果洛州 玛沁县": u"中国 青海 果洛藏族自治州 玛沁县",
        u"中国 湖南 湘西州 永顺县": u"中国 湖南 湘西土家族苗族自治州 永顺县",
        u"中国 云南 楚雄州 南华县": u"中国 云南 楚雄彝族自治州 南华县",
        u"中国 云南 红河州 开远市": u"中国 云南 红河哈尼族彝族自治州 开远市",
        u"中国 甘肃 甘南州 合作市": u"中国 甘肃 甘南藏族自治州 合作市",
        u"中国 贵州 黔东南州 天柱县": u"中国 贵州 黔东南苗族侗族自治州 天柱县",
        u"中国 四川 凉山州 会理县": u"中国 四川 凉山彝族自治州 会理县",
        u"中国 广西 河池市 环江县": u"中国 广西 河池市 环江毛南族自治县",
        u"中国 青海 果洛州 玛多县": u"中国 青海 果洛藏族自治州 玛多县",
        u"中国 云南 文山州 富宁县": u"中国 云南 文山壮族苗族自治州 富宁县",
        u"中国 湖北 恩施州 鹤峰县": u"中国 湖北 恩施土家族苗族自治州 鹤峰县",
        u"中国 内蒙古 包头市 达茂联合旗": u"中国 内蒙古 包头市 达尔罕茂明安联合旗",
        u"中国 四川 甘孜州 道孚县": u"中国 四川 甘孜藏族自治州 道孚县",
        u"中国 河北 秦皇岛市 青龙县": u"中国 河北 秦皇岛市 青龙满族自治县",
        u"中国 青海 玉树州 曲麻莱县": u"中国 青海 玉树藏族自治州 曲麻莱县",
        u"中国 青海 黄南州": u"中国 青海 黄南藏族自治州",
        u"中国 云南 大理州 剑川县": u"中国 云南 大理白族自治州 剑川县",
        u"中国 四川 甘孜州 甘孜县": u"中国 四川 甘孜藏族自治州 甘孜县",
        u"中国 贵州 黔西南州 兴义市": u"中国 贵州 黔西南布依族苗族自治州 兴义市",
        u"中国 辽宁 阜新市 阜新县": u"中国 辽宁 阜新市 阜新蒙古族自治县",
        u"中国 云南 迪庆州 德钦县": u"中国 云南 迪庆藏族自治州 德钦县",
        u"中国 新疆 伊犁州 霍城县": u"中国 新疆 伊犁哈萨克自治州 霍城县",
        u"中国 辽宁 朝阳市 喀喇沁左翼县": u"中国 辽宁 朝阳市 喀喇沁左翼蒙古族自治县",
        u"中国 湖北 恩施州 恩施市": u"中国 湖北 恩施土家族苗族自治州 恩施市",
        u"中国 贵州 黔东南州 榕江县": u"中国 贵州 黔东南苗族侗族自治州 榕江县",
        u"中国 云南 楚雄州 双柏县": u"中国 云南 楚雄彝族自治州 双柏县",
        u"中国 新疆 昌吉州 木垒县": u"中国 新疆 昌吉回族自治州 木垒哈萨克自治县",
        u"中国 青海 海东地区 互助县": u"中国 青海 海东地区 互助土族自治县",
        u"中国 广西 贺州市 富川县": u"中国 广西 贺州市 富川瑶族自治县",
        u"中国 云南 红河州 绿春县": u"中国 云南 红河哈尼族彝族自治州 绿春县",
        u"中国 云南 怒江州 贡山县": u"中国 云南 怒江傈僳族自治州 贡山独龙族怒族自治县",
        u"中国 湖南 怀化市 靖州县": u"中国 湖南 怀化市 靖州苗族侗族自治县",
        u"中国 四川 甘孜州 泸定县": u"中国 四川 甘孜藏族自治州 泸定县",
        u"中国 云南 昆明市 石林县": u"中国 云南 昆明市 石林彝族自治县",
        u"中国 新疆 克孜勒苏州 乌恰县": u"中国 新疆 克孜勒苏柯尔克孜自治州 乌恰县",
        u"中国 新疆 巴音郭楞州 库尔勒市": u"中国 新疆 巴音郭楞蒙古自治州 库尔勒市",
        u"中国 贵州 黔东南州 黎平县": u"中国 贵州 黔东南苗族侗族自治州 黎平县",
        u"中国 新疆 巴音郭楞州": u"中国 新疆 巴音郭楞蒙古自治州",
        u"中国 云南 德宏州 潞西市": u"中国 云南 德宏傣族景颇族自治州 潞西市",
        u"中国 河北 沧州市 孟村县": u"中国 河北 沧州市 孟村回族自治县",
        u"中国 贵州 黔东南州 麻江县": u"中国 贵州 黔东南苗族侗族自治州 麻江县",
        u"中国 青海 玉树州": u"中国 青海 玉树藏族自治州",
        u"中国 贵州 黔东南州 从江县": u"中国 贵州 黔东南苗族侗族自治州 从江县",
        u"中国 云南 丽江市 玉龙县": u"中国 云南 丽江市 玉龙纳西族自治县",
        u"中国 甘肃 甘南州 迭部县": u"中国 甘肃 甘南藏族自治州 迭部县",
        u"中国 云南 怒江州 福贡县": u"中国 云南 怒江傈僳族自治州 福贡县",
        u"中国 湖南 怀化市 通道县": u"中国 湖南 怀化市 通道侗族自治县",
        u"中国 云南 怒江州": u"中国 云南 怒江傈僳族自治州",
        u"中国 贵州 黔南布州": u"中国 贵州 黔南布依族苗族自治州",
        u"中国 甘肃 临夏州 临夏市": u"中国 甘肃 临夏回族自治州 临夏市",
        u"中国 云南 大理州": u"中国 云南 大理白族自治州",
        u"中国 贵州 黔东南州 镇远县": u"中国 贵州 黔东南苗族侗族自治州 镇远县",
        u"中国 贵州 黔东南州 锦屏县": u"中国 贵州 黔东南苗族侗族自治州 锦屏县",
        u"中国 浙江 丽水市 景宁县": u"中国 浙江 丽水市 景宁畲族自治县",
        u"中国 青海 海南州 同德县": u"中国 青海 海南藏族自治州 同德县",
        u"中国 青海 玉树州 杂多县": u"中国 青海 玉树藏族自治州 杂多县",
        u"中国 四川 凉山州 德昌县": u"中国 四川 凉山彝族自治州 德昌县",
        u"中国 云南 怒江州 兰坪县": u"中国 云南 怒江傈僳族自治州 兰坪白族普米族自治县",
        u"中国 甘肃 武威市 天祝县": u"中国 甘肃 武威市 天祝藏族自治县",
        u"中国 云南 文山州 马关县": u"中国 云南 文山壮族苗族自治州 马关县",
        u"中国 青海 海西州": u"中国 青海 海西蒙古族藏族自治州",
        u"中国 湖南 湘西州 泸溪县": u"中国 湖南 湘西土家族苗族自治州 泸溪县",
        u"中国 四川 凉山州 冕宁县": u"中国 四川 凉山彝族自治州 冕宁县",
        u"中国 贵州 毕节地区 威宁县": u"中国 贵州 毕节地区 威宁彝族回族苗族自治县",
        u"中国 云南 红河州 金平县": u"中国 云南 红河哈尼族彝族自治州 金平苗族瑶族傣族自治县",
        u"中国 四川 甘孜州 新龙县": u"中国 四川 甘孜藏族自治州 新龙县",
        u"中国 云南 大理州 洱源县": u"中国 云南 大理白族自治州 洱源县",
        u"中国 贵州 黔西南州": u"中国 贵州 黔西南布依族苗族自治州",
        u"中国 新疆 伊犁州 伊宁县": u"中国 新疆 伊犁哈萨克自治州 伊宁县",
        u"中国 青海 海南州": u"中国 青海 海南藏族自治州",
        u"中国 内蒙古 通辽市 科尔沁左中旗": u"中国 内蒙古 通辽市 科尔沁左翼中旗",
        u"中国 云南 文山州 西畴县": u"中国 云南 文山壮族苗族自治州 西畴县",
        u"中国 贵州 黔南州 瓮安县": u"中国 贵州 黔南布依族苗族自治州 瓮安县",
        u"中国 广西 桂林市 龙胜县": u"中国 广西 桂林市 龙胜各族自治县",
        u"中国 云南 大理州 宾川县": u"中国 云南 大理白族自治州 宾川县",
        u"中国 云南 普洱市 孟连县": u"中国 云南 普洱市 孟连傣族拉祜族佤族自治县",
        u"中国 广西 百色市 隆林县": u"中国 广西 百色市 隆林各族自治县",
        u"中国 重庆 石柱县": u"中国 重庆 石柱土家族自治县",
        u"中国 贵州 黔西南州 普安县": u"中国 贵州 黔西南布依族苗族自治州 普安县",
        u"中国 内蒙古 通辽市 科尔沁左后旗": u"中国 内蒙古 通辽市 科尔沁左翼后旗",
        u"中国 四川 甘孜州 德格县": u"中国 四川 甘孜藏族自治州 德格县",
        u"中国 新疆 博尔塔拉州 精河县": u"中国 新疆 博尔塔拉蒙古自治州 精河县",
        u"中国 青海 海西州 天峻县": u"中国 青海 海西蒙古族藏族自治州 天峻县",
        u"中国 云南 普洱市 宁洱县": u"中国 云南 普洱市 宁洱哈尼族彝族自治县",
        u"中国 新疆 伊犁州 察布查尔县": u"中国 新疆 伊犁哈萨克自治州 察布查尔锡伯自治县",
        u"中国 云南 昆明市 寻甸县": u"中国 云南 昆明市 寻甸回族彝族自治县",
        u"中国 辽宁 丹东市 宽甸县": u"中国 辽宁 丹东市 宽甸满族自治县",
        u"中国 新疆 巴音郭楞州 若羌县": u"中国 新疆 巴音郭楞蒙古自治州 若羌县",
        u"中国 吉林 延边州": u"中国 吉林 延边朝鲜族自治州",
        u"中国 新疆 巴音郭楞州 博湖县": u"中国 新疆 巴音郭楞蒙古自治州 博湖县",
        u"中国 辽宁 本溪市 桓仁县": u"中国 辽宁 本溪市 桓仁满族自治县",
        u"中国 云南 德宏州 梁河县": u"中国 云南 德宏傣族景颇族自治州 梁河县",
        u"中国 云南 德宏州 盈江县": u"中国 云南 德宏傣族景颇族自治州 盈江县",
        u"中国 青海 果洛州 久治县": u"中国 青海 果洛藏族自治州 久治县",
        u"中国 云南 西双版纳州 勐海县": u"中国 云南 西双版纳傣族自治州 勐海县",
        u"中国 云南 红河州 蒙自县": u"中国 云南 红河哈尼族彝族自治州 蒙自县",
        u"中国 贵州 黔东南州": u"中国 贵州 黔东南苗族侗族自治州",
        u"中国 新疆 昌吉州 玛纳斯县": u"中国 新疆 昌吉回族自治州 玛纳斯县",
        u"中国 青海 海东地区 循化县": u"中国 青海 海东地区 循化撒拉族自治县",
        u"中国 新疆 昌吉州 奇台县": u"中国 新疆 昌吉回族自治州 奇台县",
        u"中国 云南 迪庆州 香格里拉县": u"中国 云南 迪庆藏族自治州 香格里拉县",
        u"中国 甘肃 甘南州 舟曲县": u"中国 甘肃 甘南藏族自治州 舟曲县",
        u"中国 湖北 恩施州": u"中国 湖北 恩施土家族苗族自治州",
        u"中国 青海 海北州 刚察县": u"中国 青海 海北藏族自治州 刚察县",
        u"中国 云南 大理州 祥云县": u"中国 云南 大理白族自治州 祥云县",
        u"中国 贵州 黔东南州 剑河县": u"中国 贵州 黔东南苗族侗族自治州 剑河县",
        u"中国 河北 承德市 围场县": u"中国 河北 承德市 围场满族蒙古族自治县",
        u"中国 云南 楚雄州 永仁县": u"中国 云南 楚雄彝族自治州 永仁县",
        u"中国 四川 凉山州 西昌市": u"中国 四川 凉山彝族自治州 西昌市",
        u"中国 贵州 黔西南州 兴仁县": u"中国 贵州 黔西南布依族苗族自治州 兴仁县",
        u"中国 四川 凉山州": u"中国 四川 凉山彝族自治州",
        u"中国 贵州 黔东南州 台江县": u"中国 贵州 黔东南苗族侗族自治州 台江县",
        u"中国 云南 楚雄州 牟定县": u"中国 云南 楚雄彝族自治州 牟定县",
        u"中国 吉林 延边州 延吉市": u"中国 吉林 延边朝鲜族自治州 延吉市",
        u"中国 云南 大理州 巍山县": u"中国 云南 大理白族自治州 巍山彝族回族自治县",
        u"中国 新疆 哈密地区 巴里坤县": u"中国 新疆 哈密地区 巴里坤哈萨克自治县",
        u"中国 广西 来宾市 金秀县": u"中国 广西 来宾市 金秀瑶族自治县",
        u"中国 四川 甘孜州 丹巴县": u"中国 四川 甘孜藏族自治州 丹巴县",
        u"中国 新疆 博尔塔拉州 温泉县": u"中国 新疆 博尔塔拉蒙古自治州 温泉县",
        u"中国 新疆 巴音郭楞州 和硕县": u"中国 新疆 巴音郭楞蒙古自治州 和硕县",
        u"中国 四川 凉山州 普格县": u"中国 四川 凉山彝族自治州 普格县",
        u"中国 青海 西宁市 大通县": u"中国 青海 西宁市 大通回族土族自治县",
        u"中国 云南 临沧市 沧源县": u"中国 云南 临沧市 沧源佤族自治县",
        u"中国 甘肃 临夏州 广河县": u"中国 甘肃 临夏回族自治州 广河县",
        u"中国 青海 海西州 都兰县": u"中国 青海 海西蒙古族藏族自治州 都兰县",
        u"中国 云南 普洱市 墨江县": u"中国 云南 普洱市 墨江哈尼族自治县",
        u"中国 新疆 巴音郭楞州 且末县": u"中国 新疆 巴音郭楞蒙古自治州 且末县",
        u"中国 新疆 巴音郭楞州 和静县": u"中国 新疆 巴音郭楞蒙古自治州 和静县",
        u"中国 青海 海南州 兴海县": u"中国 青海 海南藏族自治州 兴海县",
        u"中国 甘肃 酒泉市 肃北县": u"中国 甘肃 酒泉市 肃北蒙古族自治县",
        u"中国 青海 黄南州 河南县": u"中国 青海 黄南藏族自治州 河南蒙古族自治县",
        u"中国 贵州 黔东南州 施秉县": u"中国 贵州 黔东南苗族侗族自治州 施秉县",
        u"中国 广西 河池市 都安县": u"中国 广西 河池市 都安瑶族自治县",
        u"中国 四川 凉山州 盐源县": u"中国 四川 凉山彝族自治州 盐源县",
        u"中国 甘肃 甘南州 夏河县": u"中国 甘肃 甘南藏族自治州 夏河县",
        u"中国 新疆 伊犁州 尼勒克县": u"中国 新疆 伊犁哈萨克自治州 尼勒克县",
        u"中国 青海 玉树州 称多县": u"中国 青海 玉树藏族自治州 称多县",
        u"中国 广西 柳州市 融水县": u"中国 广西 柳州市 融水苗族自治县",
        u"中国 青海 海南州 共和县": u"中国 青海 海南藏族自治州 共和县",
        u"中国 广东 清远市 连山县": u"中国 广东 清远市 连山壮族瑶族自治县",
        u"中国 广西 河池市 罗城县": u"中国 广西 河池市 罗城仫佬族自治县",
        u"中国 云南 大理州 云龙县": u"中国 云南 大理白族自治州 云龙县",
        u"中国 青海 海南州 贵德县": u"中国 青海 海南藏族自治州 贵德县",
        u"中国 贵州 安顺市 紫云县": u"中国 贵州 安顺市 紫云苗族布依族自治县",
        u"中国 云南 西双版纳州": u"中国 云南 西双版纳傣族自治州",
        u"中国 云南 楚雄州 武定县": u"中国 云南 楚雄彝族自治州 武定县",
        u"中国 云南 红河州 红河县": u"中国 云南 红河哈尼族彝族自治州 红河县",
        u"中国 云南 楚雄州 姚安县": u"中国 云南 楚雄彝族自治州 姚安县",
        u"中国 四川 凉山州 喜德县": u"中国 四川 凉山彝族自治州 喜德县",
        u"中国 贵州 铜仁地区 印江县": u"中国 贵州 铜仁地区 印江土家族苗族自治县",
        u"中国 云南 红河州 屏边县": u"中国 云南 红河哈尼族彝族自治州 屏边苗族自治县",
        u"中国 云南 楚雄州 禄丰县": u"中国 云南 楚雄彝族自治州 禄丰县",
        u"中国 云南 楚雄州 大姚县": u"中国 云南 楚雄彝族自治州 大姚县",
        u"中国 青海 海北州 祁连县": u"中国 青海 海北藏族自治州 祁连县",
        u"中国 内蒙古 乌兰察布市 察哈尔右前旗": u"中国 内蒙古 乌兰察布市 察哈尔右翼前旗",
        u"中国 辽宁 抚顺市 新宾县": u"中国 辽宁 抚顺市 新宾满族自治县",
        u"中国 甘肃 天水市 张家川县": u"中国 甘肃 天水市 张家川回族自治县",
        u"中国 四川 凉山州 甘洛县": u"中国 四川 凉山彝族自治州 甘洛县",
        u"中国 四川 凉山州 木里县": u"中国 四川 凉山彝族自治州 木里藏族自治县",
        u"中国 四川 甘孜州 雅江县": u"中国 四川 甘孜藏族自治州 雅江县",
        u"中国 云南 文山州 广南县": u"中国 云南 文山壮族苗族自治州 广南县",
        u"中国 云南 红河州 弥勒县": u"中国 云南 红河哈尼族彝族自治州 弥勒县",
        u"中国 吉林 延边州 龙井市": u"中国 吉林 延边朝鲜族自治州 龙井市",
        u"中国 贵州 铜仁地区 沿河县": u"中国 贵州 铜仁地区 沿河土家族自治县",
        u"中国 贵州 铜仁地区 松桃县": u"中国 贵州 铜仁地区 松桃苗族自治县",
        u"中国 云南 德宏州": u"中国 云南 德宏傣族景颇族自治州",
        u"中国 新疆 昌吉州": u"中国 新疆 昌吉回族自治州",
        u"中国 新疆 巴音郭楞州 轮台县": u"中国 新疆 巴音郭楞蒙古自治州 轮台县",
        u"中国 云南 楚雄州 元谋县": u"中国 云南 楚雄彝族自治州 元谋县",
        u"中国 云南 丽江市 宁蒗县": u"中国 云南 丽江市 宁蒗彝族自治县",
        u"中国 云南 楚雄州": u"中国 云南 楚雄彝族自治州",
        u"中国 四川 凉山州 雷波县": u"中国 四川 凉山彝族自治州 雷波县",
        u"中国 吉林 延边州 安图县": u"中国 吉林 延边朝鲜族自治州 安图县",
        u"中国 四川 甘孜州 康定县": u"中国 四川 甘孜藏族自治州 康定县",
        u"中国 青海 海南州 贵南县": u"中国 青海 海南藏族自治州 贵南县",
        u"中国 云南 普洱市 景东县": u"中国 云南 普洱市 景东彝族自治县",
        u"中国 云南 文山州 砚山县": u"中国 云南 文山壮族苗族自治州 砚山县",
        u"中国 广西 河池市 大化县": u"中国 广西 河池市 大化瑶族自治县",
        u"中国 四川 甘孜州 乡城县": u"中国 四川 甘孜藏族自治州 乡城县",
        u"中国 四川 凉山州 昭觉县": u"中国 四川 凉山彝族自治州 昭觉县",
        u"中国 吉林 延边州 敦化市": u"中国 吉林 延边朝鲜族自治州 敦化市",
        u"中国 云南 德宏州 瑞丽市": u"中国 云南 德宏傣族景颇族自治州 瑞丽市",
        u"中国 吉林 延边州 珲春市": u"中国 吉林 延边朝鲜族自治州 珲春市",
        u"中国 重庆 酉阳县": u"中国 重庆 酉阳土家族苗族自治县",
        u"中国 贵州 黔南州 罗甸县": u"中国 贵州 黔南布依族苗族自治州 罗甸县",
        u"中国 云南 大理州 大理市": u"中国 云南 大理白族自治州 大理市",
        u"中国 云南 昆明市 禄劝县": u"中国 云南 昆明市 禄劝彝族苗族自治县",
        u"中国 湖南 湘西州 吉首市": u"中国 湖南 湘西土家族苗族自治州 吉首市",
        u"中国 内蒙古 兴安盟 科尔沁右前旗": u"中国 内蒙古 兴安盟 科尔沁右翼前旗",
        u"中国 贵州 黔南州 贵定县": u"中国 贵州 黔南布依族苗族自治州 贵定县",
        u"中国 贵州 黔南州 平塘县": u"中国 贵州 黔南布依族苗族自治州 平塘县",
        u"中国 甘肃 甘南州 临潭县": u"中国 甘肃 甘南藏族自治州 临潭县",
        u"中国 湖南 湘西州 花垣县": u"中国 湖南 湘西土家族苗族自治州 花垣县",
        u"中国 青海 玉树州 治多县": u"中国 青海 玉树藏族自治州 治多县",
        u"中国 云南 普洱市 江城县": u"中国 云南 普洱市 江城哈尼族彝族自治县",
        u"中国 辽宁 本溪市 本溪县": u"中国 辽宁 本溪市 本溪满族自治县",
        u"中国 新疆 伊犁州 新源县": u"中国 新疆 伊犁哈萨克自治州 新源县",
        u"中国 云南 红河州 元阳县": u"中国 云南 红河哈尼族彝族自治州 元阳县",
        u"中国 青海 果洛州 甘德县": u"中国 青海 果洛藏族自治州 甘德县",
        u"中国 贵州 黔东南州 丹寨县": u"中国 贵州 黔东南苗族侗族自治州 丹寨县",
        u"中国 辽宁 鞍山市 岫岩县": u"中国 辽宁 鞍山市 岫岩满族自治县",
        u"中国 贵州 黔西南州 晴隆县": u"中国 贵州 黔西南布依族苗族自治州 晴隆县",
        u"中国 新疆 博尔塔拉州": u"中国 新疆 博尔塔拉蒙古自治州",
        u"中国 新疆 伊犁州 昭苏县": u"中国 新疆 伊犁哈萨克自治州 昭苏县",
        u"中国 贵州 黔南州 独山县": u"中国 贵州 黔南布依族苗族自治州 独山县",
        u"中国 吉林 松原市 前郭尔罗斯县": u"中国 吉林 松原市 前郭尔罗斯蒙古族自治县",
        u"中国 贵州 黔东南州 凯里市": u"中国 贵州 黔东南苗族侗族自治州 凯里市",
        u"中国 新疆 喀什地区 塔什库尔干县": u"中国 新疆 喀什地区 塔什库尔干塔吉克自治县",
        u"中国 四川 甘孜州 理塘县": u"中国 四川 甘孜藏族自治州 理塘县",
        u"中国 云南 文山州 文山县": u"中国 云南 文山壮族苗族自治州 文山县",
        u"中国 甘肃 甘南州": u"中国 甘肃 甘南藏族自治州",
        u"中国 新疆 伊犁州 奎屯市": u"中国 新疆 伊犁哈萨克自治州 奎屯市",
        u"中国 湖北 恩施州 建始县": u"中国 湖北 恩施土家族苗族自治州 建始县",
        u"中国 广东 清远市 连南县": u"中国 广东 清远市 连南瑶族自治县",
        u"中国 新疆 昌吉州 吉木萨尔县": u"中国 新疆 昌吉回族自治州 吉木萨尔县",
        u"中国 新疆 伊犁州 特克斯县": u"中国 新疆 伊犁哈萨克自治州 特克斯县",
        u"中国 云南 楚雄州 楚雄市": u"中国 云南 楚雄彝族自治州 楚雄市",
        u"中国 云南 玉溪市 新平县": u"中国 云南 玉溪市 新平彝族傣族自治县",
        u"中国 湖南 怀化市 芷江县": u"中国 湖南 怀化市 芷江侗族自治县",
        u"中国 辽宁 抚顺市 清原县": u"中国 辽宁 抚顺市 清原满族自治县",
        u"中国 青海 海北州": u"中国 青海 海北藏族自治州",
        u"中国 青海 海西州 格尔木市": u"中国 青海 海西蒙古族藏族自治州 格尔木市",
        u"中国 河北 承德市 丰宁县": u"中国 河北 承德市 丰宁满族自治县",
        u"中国 贵州 安顺市 关岭县": u"中国 贵州 安顺市 关岭布依族苗族自治县",
        u"中国 甘肃 临夏州 永靖县": u"中国 甘肃 临夏回族自治州 永靖县",
        u"中国 云南 文山州": u"中国 云南 文山壮族苗族自治州",
        u"中国 四川 甘孜州 巴塘县": u"中国 四川 甘孜藏族自治州 巴塘县",
        u"中国 云南 怒江州 泸水县": u"中国 云南 怒江傈僳族自治州 泸水县",
        u"中国 云南 红河州 建水县": u"中国 云南 红河哈尼族彝族自治州 建水县",
        u"中国 重庆 彭水县": u"中国 重庆 彭水苗族土家族自治县",
        u"中国 新疆 巴音郭楞州 尉犁县": u"中国 新疆 巴音郭楞蒙古自治州 尉犁县",
        u"中国 云南 临沧市 双江县": u"中国 云南 临沧市 双江拉祜族佤族布朗族傣族自治县",
        u"中国 青海 果洛州": u"中国 青海 果洛藏族自治州",
        u"中国 四川 甘孜州 九龙县": u"中国 四川 甘孜藏族自治州 九龙县",
        u"中国 广西 柳州市 三江县": u"中国 广西 柳州市 三江侗族自治县",
        u"中国 湖南 湘西州 保靖县": u"中国 湖南 湘西土家族苗族自治州 保靖县",
        u"中国 四川 凉山州 越西县": u"中国 四川 凉山彝族自治州 越西县",
        u"中国 湖南 怀化市 新晃县": u"中国 湖南 怀化市 新晃侗族自治县",
        u"中国 贵州 黔南州 龙里县": u"中国 贵州 黔南布依族苗族自治州 龙里县",
        u"中国 云南 普洱市 景谷县": u"中国 云南 普洱市 景谷傣族彝族自治县",
        u"中国 湖北 恩施州 来凤县": u"中国 湖北 恩施土家族苗族自治州 来凤县",
        u"中国 云南 迪庆州 维西县": u"中国 云南 迪庆藏族自治州 维西傈僳族自治县",
        u"中国 湖南 邵阳市 城步县": u"中国 湖南 邵阳市 城步苗族自治县",
        u"中国 吉林 延边州 和龙市": u"中国 吉林 延边朝鲜族自治州 和龙市",
        u"中国 云南 红河州 泸西县": u"中国 云南 红河哈尼族彝族自治州 泸西县",
        u"中国 贵州 黔西南州 望谟县": u"中国 贵州 黔西南布依族苗族自治州 望谟县",
        u"中国 四川 凉山州 布拖县": u"中国 四川 凉山彝族自治州 布拖县",
        u"中国 四川 凉山州 宁南县": u"中国 四川 凉山彝族自治州 宁南县",
        u"中国 贵州 黔东南州 岑巩县": u"中国 贵州 黔东南苗族侗族自治州 岑巩县",
        u"中国 湖北 恩施州 咸丰县": u"中国 湖北 恩施土家族苗族自治州 咸丰县",
        u"中国 云南 西双版纳州 勐腊县": u"中国 云南 西双版纳傣族自治州 勐腊县",
        u"中国 云南 普洱市 西盟县": u"中国 云南 普洱市 西盟佤族自治县",
        u"中国 云南 德宏州 陇川县": u"中国 云南 德宏傣族景颇族自治州 陇川县",
        u"中国 贵州 黔西南州 安龙县": u"中国 贵州 黔西南布依族苗族自治州 安龙县",
        u"中国 四川 阿坝州": u"中国 四川 阿坝藏族羌族自治州",
        u"中国 湖北 恩施州 巴东县": u"中国 湖北 恩施土家族苗族自治州 巴东县",
        u"中国 贵州 黔西南州 册亨县": u"中国 贵州 黔西南布依族苗族自治州 册亨县",
        u"中国 贵州 黔东南州 雷山县": u"中国 贵州 黔东南苗族侗族自治州 雷山县",
        u"中国 新疆 昌吉州 阜康市": u"中国 新疆 昌吉回族自治州 阜康市",
        u"中国 青海 黄南州 同仁县": u"中国 青海 黄南藏族自治州 同仁县",
        u"中国 云南 普洱市 澜沧县": u"中国 云南 普洱市 澜沧拉祜族自治县",
        u"中国 新疆 伊犁州 伊宁市": u"中国 新疆 伊犁哈萨克自治州 伊宁市",
        u"中国 青海 玉树州 囊谦县": u"中国 青海 玉树藏族自治州 囊谦县",
        u"中国 湖南 湘西州": u"中国 湖南 湘西土家族苗族自治州",
        u"中国 吉林 延边州 图们市": u"中国 吉林 延边朝鲜族自治州 图们市",
        u"中国 云南 大理州 南涧县": u"中国 云南 大理白族自治州 南涧彝族自治县",
        u"中国 贵州 遵义市 务川县": u"中国 贵州 遵义市 务川仡佬族苗族自治县",
        u"中国 新疆 昌吉州 昌吉市": u"中国 新疆 昌吉回族自治州 昌吉市",
        u"中国 云南 大理州 漾濞县": u"中国 云南 大理白族自治州 漾濞彝族自治县",
        u"中国 新疆 伊犁州": u"中国 新疆 伊犁哈萨克自治州",
        u"中国 青海 果洛州 达日县": u"中国 青海 果洛藏族自治州 达日县",
        u"中国 贵州 黔南州 荔波县": u"中国 贵州 黔南布依族苗族自治州 荔波县",
        u"中国 甘肃 临夏州 康乐县": u"中国 甘肃 临夏回族自治州 康乐县",
        u"中国 云南 大理州 永平县": u"中国 云南 大理白族自治州 永平县",
        u"中国 四川 甘孜州 石渠县": u"中国 四川 甘孜藏族自治州 石渠县",
        u"中国 云南 红河州 个旧市": u"中国 云南 红河哈尼族彝族自治州 个旧市",
        u"中国 吉林 四平市 伊通县": u"中国 吉林 四平市 伊通满族自治县",
        u"中国 云南 红河州": u"中国 云南 红河哈尼族彝族自治州",
        u"中国 四川 甘孜州 炉霍县": u"中国 四川 甘孜藏族自治州 炉霍县",
        u"中国 新疆 克孜勒苏州": u"中国 新疆 克孜勒苏柯尔克孜自治州",
        u"中国 贵州 铜仁地区 玉屏县": u"中国 贵州 铜仁地区 玉屏侗族自治县",
        u"中国 河北 廊坊市 大厂县": u"中国 河北 廊坊市 大厂回族自治县",
        u"中国 云南 大理州 弥渡县": u"中国 云南 大理白族自治州 弥渡县",
        u"中国 云南 迪州": u"中国 云南 迪庆藏族自治州",
        u"中国 云南 文山州 丘北县": u"中国 云南 文山壮族苗族自治州 丘北县",
        u"中国 云南 红河州 河口县": u"中国 云南 红河哈尼族彝族自治州 河口瑶族自治县",
        u"中国 四川 甘孜州 白玉县": u"中国 四川 甘孜藏族自治州 白玉县",
        u"中国 甘肃 临夏州 临夏县": u"中国 甘肃 临夏回族自治州 临夏县",
        u"中国 新疆 伊犁州 巩留县": u"中国 新疆 伊犁哈萨克自治州 巩留县",
        u"中国 内蒙古 乌兰察布市 察哈尔右后旗": u"中国 内蒙古 乌兰察布市 察哈尔右翼后旗",
        u"中国 青海 海北州 门源县": u"中国 青海 海北藏族自治州 门源回族自治县",
        u"中国 青海 黄南州 尖扎县": u"中国 青海 黄南藏族自治州 尖扎县",
        u"中国 甘肃 甘南州 碌曲县": u"中国 甘肃 甘南藏族自治州 碌曲县",
        u"中国 湖北 宜昌市 长阳县": u"中国 湖北 宜昌市 长阳土家族自治县",
        u"中国 新疆 昌吉州 呼图壁县": u"中国 新疆 昌吉回族自治州 呼图壁县",
        u"中国 甘肃 酒泉市 阿克塞县": u"中国 甘肃 酒泉市 阿克塞哈萨克族自治县",
        u"中国 甘肃 临夏州 东乡族自治县": u"中国 甘肃 临夏回族自治州 东乡族自治县",
        u"中国 湖北 宜昌市 五峰县": u"中国 湖北 宜昌市 五峰土家族自治县",
        u"中国 云南 红河州 石屏县": u"中国 云南 红河哈尼族彝族自治州 石屏县",
        u"中国 吉林 延边州 汪清县": u"中国 吉林 延边朝鲜族自治州 汪清县",
        u"中国 贵州 黔南州 都匀市": u"中国 贵州 黔南布依族苗族自治州 都匀市",
        u"中国 广西 河池市 巴马县": u"中国 广西 河池市 巴马瑶族自治县",
        u"中国 甘肃 甘南州 玛曲县": u"中国 甘肃 甘南藏族自治州 玛曲县",
        u"中国 甘肃 临夏州 和政县": u"中国 甘肃 临夏回族自治州 和政县",
        u"中国 湖南 湘西州 凤凰县": u"中国 湖南 湘西土家族苗族自治州 凤凰县",
        u"中国 四川 凉山州 金阳县": u"中国 四川 凉山彝族自治州 金阳县",
        u"中国 四川 甘孜州": u"中国 四川 甘孜藏族自治州",
        u'中国 四川 阿坝州 汶川县': u'中国 四川 阿坝藏族羌族自治州 汶川县',
        u'中国 四川 阿坝州 理县': u'中国 四川 阿坝藏族羌族自治州 理县',
        u'中国 四川 阿坝州 茂县': u'中国 四川 阿坝藏族羌族自治州 茂县',
        u'中国 四川 阿坝州 松潘县': u'中国 四川 阿坝藏族羌族自治州 松潘县',
        u'中国 四川 阿坝州 九寨沟县': u'中国 四川 阿坝藏族羌族自治州 九寨沟县',
        u'中国 四川 阿坝州 金川县': u'中国 四川 阿坝藏族羌族自治州 金川县',
        u'中国 四川 阿坝州 小金县': u'中国 四川 阿坝藏族羌族自治州 小金县',
        u'中国 四川 阿坝州 黑水县': u'中国 四川 阿坝藏族羌族自治州 黑水县',
        u'中国 四川 阿坝州 马尔康县': u'中国 四川 阿坝藏族羌族自治州 马尔康县',
        u'中国 四川 阿坝州 壤塘县': u'中国 四川 阿坝藏族羌族自治州 壤塘县',
        u'中国 四川 阿坝州 阿坝县': u'中国 四川 阿坝藏族羌族自治州 阿坝县',
        u'中国 四川 阿坝州 若尔盖县': u'中国 四川 阿坝藏族羌族自治州 若尔盖县',
        u'中国 四川 阿坝州 红原县': u'中国 四川 阿坝藏族羌族自治州 红原县'
    }

    if name in mappings:
        return mappings[name]
    return name
